#
# spec file for package sscep
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2016-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sscep
Version:        0.10.0
Release:        2.3
Summary:        A command line client for the SCEP protocol
License:        BSD-3-Clause-Attribution AND OpenSSL
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/certnanny/sscep
Source:         https://github.com/certnanny/sscep/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel >= 1.1.0

%description
Simple SCEP (Simple Certificate Enrollment Protocol) client with
modifications for engine support & more.

%prep
%setup -q

%build
%cmake -DENABLE_ENGINES=ON
%cmake_build

%install
%cmake_install
install -Dpm 0644 sscep.conf %{buildroot}%{_sysconfdir}/sscep/sscep.conf
install -Dpm 0755 mkrequest %{buildroot}%{_bindir}

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%dir %{_sysconfdir}/sscep/
%config(noreplace) %{_sysconfdir}/sscep/sscep.conf
%{_bindir}/sscep
%{_bindir}/mkrequest

%changelog
* Tue Feb 25 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Explicitly call cmake_build in %%build section. Do not rely on
  cmake_install building later on.
* Wed Sep 29 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.10.0
  * Added auto-selection of default protection algorithms (-E, -S
    and -F) based on getcaps, unless specified explicitly.
  * Added parameter -W sec to wait for network connectivity
    (default 0).
  * Engines are now disabled by default and need to be enabled by
    ./configure --enable-engines or cmake . -DENABLE_ENGINES=ON
  * Compatible with OpenSSL 3.0.0
  * Removed support for OpenSSL < 1.1.0
* Thu Aug 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.1
  * Fixed missing Host header.
  * Fixed multiple numeric overflows.
* Mon Feb  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.0
  * Added -E options for aes128, aes192 and aes256.
  * Changed semantics of -E aes. Per RFC8894, plain aes is equal
    to aes128. (Before 0.9.0 it was aes256.)
  * Implemented mechanism to auto-detect CA certificates (-c)
  * Fixed handling of Content-Type headers with a charset defined
  * Fixed Content-Type handling in GetCACaps responses
  * Fixed global variable declaration for building using GCC 10
- Drop not longer needed patches:
  * 0001-Fixed-handling-of-Content-Type-with-a-charset-124.patch
  * 0002-Global-variables-need-to-be-declared-using-extern.patch
* Fri Jan  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  * Added support for HTTP/1.1
  * Added support for IPv6
  * Added GetCACaps (getcaps) operation
  * Added support for POST method for PKI operations
  * Added options for additional hashing algorithms
  * Added support for autoconf/automake and CMake
  * Changed project directory layout to match the conventions
  * Fixed encoding of 'issuer and subject' and 'issuer and serial'
  * Fixed crashes when sscep is used with an OpenSSL engine
  * Replaced GNU getopt by a BSD licensed alternative
* Sun Jun  7 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon to workaround GCC10 compilation issues
* Fri Apr 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to latest release, version 0.7.0
- Specfile cleanup
* Fri Dec  2 2016 mardnh@gmx.de
- initial package
